* {margin:0; padding:0;}

html, body {
  background-color:#000;
  height:100%;
  text-align:center;
}

#movie {
  margin:0 auto;
  width:600px;
  height:480px;
}

#channels {
  background-color:#333;
  border-bottom:1px solid #ededed;
  margin-bottom:15px;
  padding:10px 0;
}

#channels div { display:inline; }

#favgrp { width:120px; }
#favlist { width:200px; }

